@@ -8,17 +8,7 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_cloudwatch._jsii
-import aws_cdk.aws_cognito._jsii
-import aws_cdk.aws_dynamodb._jsii
-import aws_cdk.aws_elasticsearch._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_lambda_event_sources._jsii
-import aws_cdk.aws_sqs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.aws_dynamodbstreams_lambda._jsii
 import aws_solutions_constructs.aws_lambda_elasticsearch_kibana._jsii
 import aws_solutions_constructs.core._jsii
@@ -26,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-dynamodbstreams-lambda-elasticsearch-kibana",
-    "1.181.1",
+    "2.0.0",
     __name__[0:-6],
-    "aws-dynamodbstreams-lambda-elasticsearch-kibana@1.181.1.jsii.tgz",
+    "aws-dynamodbstreams-lambda-elasticsearch-kibana@2.0.0.jsii.tgz",
 )
 
 __all__ = [
